#include "WidgetGallery.h"
#include "DialogWidgets.h"
#include "EventDisplayer.h"

#include <Wt/WMenu>
#include <Wt/WSubMenuItem>
#include <Wt/WHBoxLayout>
#include <Wt/WVBoxLayout>
#include <Wt/WStackedWidget>
#include <Wt/WText>

using namespace Wt;

WidgetGallery::WidgetGallery()
        : WContainerWidget()
{
    contentsStack_ = new WStackedWidget();
    // Show scrollbars when needed ...
    contentsStack_->setOverflow(WContainerWidget::OverflowAuto);
    // ... and work around a bug in IE (see setOverflow() documentation)
    contentsStack_->setPositionScheme(Relative);
    contentsStack_->setStyleClass("contents");

    EventDisplayer *eventDisplayer = new EventDisplayer(0);

    /*
     * Setup the menu (and submenus)
     */
    WMenu *menu = new WMenu(contentsStack_, Vertical, 0);
    menu->setRenderAsList(true);
    menu->setStyleClass("menu");
    menu->setInternalPathEnabled();
    menu->setInternalBasePath("/");

    addToMenu(menu, "Dialogs", new DialogWidgets(eventDisplayer));
    /*
     * Add it all inside a layout
     */
    WHBoxLayout *horizLayout = new WHBoxLayout(this);
    WVBoxLayout *vertLayout = new WVBoxLayout;

    horizLayout->addWidget(menu, 0);
    horizLayout->addLayout(vertLayout, 1);
    vertLayout->addWidget(contentsStack_, 1);
    vertLayout->addWidget(eventDisplayer);

    horizLayout->setResizable(0, true);
}

void WidgetGallery::addToMenu(WMenu *menu, const WString& name,
                              ControlsWidget *controls)
{
    if (controls->hasSubMenu())
    {
        WSubMenuItem *smi = new WSubMenuItem(name, controls);
        WMenu *subMenu = new WMenu(contentsStack_, Vertical, 0);
        subMenu->setRenderAsList(true);

        smi->setSubMenu(subMenu);
        menu->addItem(smi);

        subMenu->setInternalPathEnabled();
        subMenu->setInternalBasePath("/" + smi->pathComponent());
        subMenu->setStyleClass("menu submenu");

        controls->populateSubMenu(subMenu);
    }
    else
        menu->addItem(name, controls);
}
